@@ -19,9 +19,16 @@ class NgraphSpellchecker
   IGNORE = 3
   APPLY = 4
   APPLY_ALL = 5
+  DICT_LANG = "en_US"
 
   def initialize
-    @speller = Aspell.new("en_US")
+    snap = ENV["SNAP"]
+    p snap
+    if (snap)
+      @speller = Aspell.new1("lang" => DICT_LANG, "prefix" => "#{snap}/usr")
+    else
+      @speller = Aspell.new(DICT_LANG)
+    end
     @speller.suggestion_mode = Aspell::NORMAL
     @speller.set_option("ignore-case", "true")
 
@@ -40,7 +47,7 @@ class NgraphSpellchecker
     return nil unless (@menu)
     inst = @menu.focused("text")
     if (inst.empty?)
-      nil 
+      nil
     else
       inst.map {|inst| Ngraph.str2inst(inst)[0]}
     end
@@ -145,7 +152,11 @@ class NgraphSpellchecker
   end
 
   def check(text)
-    original_string = text.text
+    original_string = if (text.instance_of?(Ngraph::Text))
+			text.text
+		      else
+			text.title
+		      end
     modified_string = ""
     word = ""
 
@@ -185,7 +196,11 @@ class NgraphSpellchecker
     end
 
     if (original_string != modified_string)
-      text.text = modified_string
+      if (text.instance_of?(Ngraph::Text))
+	text.text = modified_string
+      else
+	text.title = modified_string
+      end
       @modified = true
     end
     r
@@ -201,6 +216,9 @@ class NgraphSpellchecker
     Ngraph::Text.each {|text|
       break unless (check(text))
     }
+    Ngraph::Parameter.each {|text|
+      break unless (check(text))
+    }
   end
 
   def run
@@ -216,7 +234,7 @@ class NgraphSpellchecker
   def finalize
     Ngraph::Dialog.new {|dialog|
       dialog.title = "spell check"
-      str = dialog.message("Spell check completed.")
+      dialog.message("Spell check completed.")
     }
     if (@menu && @modified)
       @menu.modified = true
