@@ -108,7 +108,7 @@ static struct ngraph_instance *
 check_id(VALUE klass)
 {
   struct ngraph_instance *inst;
-  int id, r, last;
+  int id, last;
   ngraph_arg arg;
   ngraph_returned_value oid;
 
@@ -120,6 +120,7 @@ check_id(VALUE klass)
 
   last = ngraph_get_object_last_id(inst->obj);
   if (inst->id <= last) {
+    int r;
     arg.num = 0;
     r = ngraph_object_get(inst->obj, "oid", inst->id, &arg, &oid);
 
@@ -1086,7 +1087,7 @@ inst_put_iarray(VALUE self, VALUE arg, const char *field)
   VALUE tmpstr;
   struct ngraph_instance *inst;
   ngraph_value ary;
-  int num, i;
+  int num;
 
   inst = check_id(self);
   if (inst == NULL) {
@@ -1108,6 +1109,7 @@ inst_put_iarray(VALUE self, VALUE arg, const char *field)
     ary.ary = rb_alloc_tmp_buffer(&tmpstr, sizeof(*ary.ary) + sizeof(ngraph_value) * num);
     ary.ary->num = num;
     if (ary.ary) {
+      int i;
       for (i = 0; i < num; i++) {
         ary.ary->ary[i].i = NUM2INT(rb_ary_entry(arg, i));
       }
@@ -1161,7 +1163,7 @@ inst_put_darray(VALUE self, VALUE arg, const char *field)
   VALUE tmpstr;
   struct ngraph_instance *inst;
   ngraph_value ary;
-  int num, i;
+  int num;
 
   inst = check_id(self);
   if (inst == NULL) {
@@ -1183,6 +1185,7 @@ inst_put_darray(VALUE self, VALUE arg, const char *field)
     ary.ary = rb_alloc_tmp_buffer(&tmpstr, sizeof(*ary.ary) + sizeof(ngraph_value) * num);
     ary.ary->num = num;
     if (ary.ary) {
+      int i;
       for (i = 0; i < num; i++) {
         ary.ary->ary[i].d = NUM2DBL(rb_ary_entry(arg, i));
       }
@@ -1235,7 +1238,7 @@ inst_put_sarray(VALUE self, VALUE arg, const char *field)
 {
   struct ngraph_instance *inst;
   ngraph_value ary;
-  int num, i;
+  int num;
   VALUE str, tmpstr;
 
   inst = check_id(self);
@@ -1258,6 +1261,7 @@ inst_put_sarray(VALUE self, VALUE arg, const char *field)
     ary.ary =  rb_alloc_tmp_buffer(&tmpstr, sizeof(*ary.ary) + sizeof(ngraph_value) * num);
     ary.ary->num = num;
     if (ary.ary) {
+      int i;
       for (i = 0; i < num; i++) {
         str = rb_ary_entry(arg, i);
         ary.ary->ary[i].str = StringValueCStr(str);
@@ -1463,7 +1467,7 @@ static VALUE
 obj_func_obj(VALUE self, VALUE argv, const char *field, int type)
 {
   VALUE arg, rstr, val;
-  int i, n;
+  int i;
   struct ngraph_instance *inst;
   ngraph_arg carg;
   int argc;
@@ -1481,6 +1485,7 @@ obj_func_obj(VALUE self, VALUE argv, const char *field, int type)
   } else {
     arg = rb_ary_entry(argv, 0);
     if (RB_TYPE_P(arg, T_ARRAY)) {
+      int n;
       if (argc > 1) {
 	return Qnil;
       }
@@ -1585,13 +1590,13 @@ get_str_func_argv(VALUE self, VALUE argv, const char *field)
 static void
 add_obj_name_const(VALUE klass, struct objlist *nobj, const char *name)
 {
-  const char *obj_name;
-  char str[64];
   VALUE val;
 
   if (nobj == NULL) {
     val = Qnil;
   } else {
+    const char *obj_name;
+    char str[64];
     obj_name = ngraph_get_object_name(nobj);
     set_ngraph_obj_class_name(obj_name, str, sizeof(str));
     val = ID2SYM(rb_intern(str));
@@ -1781,8 +1786,6 @@ static VALUE
 ruby_ngraph_exec_loginshell(VALUE module, VALUE cmd, VALUE nobj)
 {
   int r;
-  size_t len;
-  const char *str;
   char *loginshell;
   static struct ngraph_instance *inst;
 
@@ -1793,6 +1796,8 @@ ruby_ngraph_exec_loginshell(VALUE module, VALUE cmd, VALUE nobj)
   if (NIL_P(cmd)) {
     loginshell = NULL;
   } else {
+    size_t len;
+    const char *str;
     str = StringValueCStr(cmd);
     len = strlen(str) + 1;
     loginshell = ALLOCA_N(char, len);
@@ -1835,7 +1840,6 @@ load_script(int argc, char **argv)
   rb_protect(wrap_load_script, fname, &state);
   if (state) {
     VALUE errinfo, errstr, errat;
-    int n, i;
     const char *cstr;
 
     errinfo = rb_errinfo();
@@ -1845,6 +1849,7 @@ load_script(int argc, char **argv)
       ngraph_err_puts(cstr);
       errat = rb_funcall(errinfo, rb_intern("backtrace"), 0);
       if (! NIL_P(errat)) {
+        int n;
 	n = RARRAY_LEN(errat);
 	for (i = 0; i < n; i ++) {
 	  errstr = rb_str_new2("\tfrom ");
