@@ -7,6 +7,7 @@
 
 #include "common.h"
 
+#include "gtk_common.h"
 #include "gtk_liststore.h"
 
 #include "object.h"
@@ -28,6 +29,7 @@ struct subwin_popup_list {
 GtkWidget *label_sub_window_create(struct SubWin *d);
 GtkWidget *text_sub_window_create(struct SubWin *d);
 GtkWidget *list_sub_window_create(struct SubWin *d, int lisu_num, n_list_store *list);
+GtkWidget *parameter_sub_window_create(struct SubWin *d);
 GtkWidget *tree_sub_window_create(struct SubWin *d, int page_num, int *lisu_num, n_list_store **list, GtkWidget **icons);
 void sub_window_set_geometry(struct SubWin *d, int resize);
 void sub_window_save_geometry(struct SubWin *d);
@@ -52,8 +54,8 @@ void list_sub_window_move_last(GtkMenuItem *item, gpointer user_data);
 void list_sub_window_move_up(GtkMenuItem *item, gpointer user_data);
 void list_sub_window_move_down(GtkMenuItem *item, gpointer user_data);
 void list_sub_window_update(GtkMenuItem *item, gpointer user_data);
-void list_sub_window_hide(GtkMenuItem *item, gpointer user_data);
 void list_sub_window_focus(GtkMenuItem *item, gpointer user_data);
+void list_sub_window_focus_all(GtkMenuItem *item, gpointer user_data);
 void list_sub_window_add_focus(GtkMenuItem *item, gpointer user_data);
 
 void tree_sub_window_delete(GtkMenuItem *item, gpointer user_data);
