@@ -457,10 +457,10 @@ dlgspin(struct objlist *obj, N_VALUE *inst, N_VALUE *rval, int argc, char **argv
   type = argv[1][0];
   switch (type) {
   case 'd':
-    min = * (double *) argv[2];
-    max = * (double *) argv[3];
-    inc = * (double *) argv[4];
-    r = * (double *) argv[5];
+    min = arg_to_double(argv, 2);
+    max = arg_to_double(argv, 3);
+    inc = arg_to_double(argv, 4);
+    r   = arg_to_double(argv, 5);
     break;
   case 'i':
     min = * (int *) argv[2];
@@ -503,7 +503,7 @@ dlgspin(struct objlist *obj, N_VALUE *inst, N_VALUE *rval, int argc, char **argv
 static int
 dlgcheck(struct objlist *obj, N_VALUE *inst, N_VALUE *rval, int argc, char **argv)
 {
-  int locksave, *r, i, n, inum, *ptr, x, y, ret;
+  int locksave, *r, i, n, inum, x, y, ret;
   struct narray *array, *sarray, *iarray;
   char *title, *caption;
   struct narray *buttons;
@@ -554,6 +554,7 @@ dlgcheck(struct objlist *obj, N_VALUE *inst, N_VALUE *rval, int argc, char **arg
 
   inum = arraynum(iarray);
   for (i = 0; i < inum; i++) {
+    int *ptr;
     ptr = (int *) arraynget(iarray, i);
     if (ptr && *ptr >= 0 && *ptr < n)
       r[*ptr] = 1;
@@ -649,11 +650,11 @@ dlggetopenfiles(struct objlist *obj, N_VALUE *inst, N_VALUE *rval,
 {
   struct narray *array;
   char **d;
-  int anum, i;
+  int anum;
   char *filter = NULL, *initfile = NULL;
   int locksave;
   int ret;
-  char **file = NULL, *name;
+  char **file = NULL;
   struct narray *farray;
 
   locksave = Globallock;
@@ -679,10 +680,11 @@ dlggetopenfiles(struct objlist *obj, N_VALUE *inst, N_VALUE *rval,
   ret = nGetOpenFileNameMulti(get_toplevel_window(), _("Open files"),
 			      filter, NULL, initfile, &file, TRUE);
   if (ret == IDOK) {
+    int i;
     farray = arraynew(sizeof(char *));
     for (i = 0; file[i]; i++) {
       changefilename(file[i]);
-      arrayadd(farray, &name);
+      arrayadd(farray, file + i);
     }
     rval->array = farray;
   }
