@@ -30,13 +30,17 @@
 #include <gdk/gdk.h>
 
 #include "object.h"
+#include "ofit.h"
 #include "ogra2cairo.h"
 #include "x11menu.h"
 
 #define MATH_FNC_NUM 5
+#define AXIS_SELECTION_LIMIT 6
 
+#define LINE_STYLE_ELEMENT_MAX 6
 struct line_style {
   char *name, *list;
+  int nlist[LINE_STYLE_ELEMENT_MAX];
   int num;
 };
 
@@ -44,6 +48,12 @@ extern struct line_style FwLineStyle[];
 extern char *FwNumStyle[];
 extern int FwNumStyleNum;
 
+enum AXIS_COMBO_BOX_FLAGS {
+  AXIS_COMBO_BOX_NONE = 0,
+  AXIS_COMBO_BOX_USE_OID = 1,
+  AXIS_COMBO_BOX_ADD_NONE = 2,
+};
+
 #define N_RESPONSE_ALL 1
 
 void initdialog(void);
@@ -55,6 +65,8 @@ int SetObjPointsFromText(GtkWidget *w, struct objlist *Obj, int Id, char *field)
 void SetTextFromObjPoints(GtkWidget *w, struct objlist *Obj, int Id, char *field);
 int SetObjFieldFromStyle(GtkWidget *w, struct objlist *Obj, int Id, char *field);
 void SetStyleFromObjField(GtkWidget *w, struct objlist *Obj, int Id, char *field);
+GtkWidget *axis_combo_box_create(int flags);
+void axis_combo_box_setup(GtkWidget *cbox, struct objlist *obj, int id, const char *field);
 int SetObjAxisFieldFromWidget(GtkWidget *w, struct objlist *obj, int id, char *field);
 struct compatible_font_info *SetFontListFromObj(GtkWidget *w, struct objlist *obj, int id, const char *name);
 void SetObjFieldFromFontList(GtkWidget *w, struct objlist *obj, int id, char *name);
@@ -172,7 +184,7 @@ struct MathTextDialog
 };
 void MathTextDialog(struct MathTextDialog *data, char *text, int mode, struct objlist *obj, GList *list, GtkWidget *tree);
 
-#define FIT_PARM_NUM 10
+#define FIT_PARM_NUM FIT_DIMENSION_MAX
 
 struct FitDialog
 {
@@ -391,9 +403,10 @@ struct PageDialog
 {
   DIALOG_PROTOTYPE;
   /****** local member *******/
-  GtkWidget *leftmargin, *topmargin, *paperwidth, *paperheight, *paperzoom, *paper, *decimalsign;
+  GtkWidget *leftmargin, *topmargin, *paperwidth, *paperheight, *paperzoom, *paper, *decimalsign, *portrait, *landscape;
+  int new_graph;
 };
-void PageDialog(struct PageDialog *data);
+void PageDialog(struct PageDialog *data, int new_graph);
 
 struct SwitchDialog
 {
@@ -495,7 +508,7 @@ struct MiscDialog
   GtkWidget *editor, *directory, *path, *datafile,
     *expand, *expanddir, *loadpath, *mergefile, *coordwin_font, *infowin_font,
     *file_preview_font, *hist_size, *info_size, *data_head_lines, *help_browser,
-    *browser, *use_opacity, *select_data, *use_custom_palette, *source_style,
+    *browser, *use_opacity, *select_data, *use_custom_palette, *use_dark_theme, *source_style,
     *decimalsign;
   struct objlist *Obj;
   struct narray tmp_palette;
@@ -587,6 +600,7 @@ extern struct SectionDialog DlgSection;
 extern struct CrossDialog DlgCross;
 extern struct AxisDialog DlgAxis;
 extern struct GridDialog DlgGrid;
+extern struct GridDialog DlgGridDef;
 extern struct ZoomDialog DlgZoom;
 extern struct AxisBaseDialog DlgAxisBase;
 extern struct AxisPosDialog DlgAxisPos;
