@@ -112,9 +112,9 @@ static gboolean
 LegendGaussDialogPaint(GtkWidget *w, cairo_t *cr, gpointer client_data)
 {
   struct LegendGaussDialog *d;
-  int i, j, k, pw, dw, minx, miny, maxx, maxy,
-    amp, wd, GC, spnum, output, found;
-  double ppd, x, y = 0, tmp, spc2[6], dashes[] = {4.0};
+  int pw, dw, minx, miny, maxx, maxy,
+    amp, wd, output, found;
+  double ppd, dashes[] = {4.0};
   GdkWindow *win;
   struct objlist *gobj, *robj;
   N_VALUE *inst;
@@ -160,10 +160,13 @@ LegendGaussDialogPaint(GtkWidget *w, cairo_t *cr, gpointer client_data)
   }
 
   if (d->alloc) {
+    int GC;
     GC = _GRAopen("gra2gdk", "_output",
 		  robj, inst, output, -1, -1, -1, NULL, local);
     GRAlinestyle(GC, 0, NULL, 1, GRA_LINE_CAP_BUTT, GRA_LINE_JOIN_MITER, 1000);
     if (GC >= 0) {
+      int i, j, k, spnum;
+      double tmp, y = 0, spc2[6];
       GRAview(GC, minx, miny, maxx, maxy, 1);
 
       if (d->Div > DIV_MAX) {
@@ -171,6 +174,7 @@ LegendGaussDialogPaint(GtkWidget *w, cairo_t *cr, gpointer client_data)
       }
 
       for (i = 0; i <= (d->Div); i++) {
+        double x;
 	x = wd / ((double) (d->Div)) * i;
 	if (d->Mode == 0) {
 	  tmp = (x - wd * 0.5 - wd * d->Position * 0.5) /
@@ -284,11 +288,11 @@ static int
 get_radio_index(GSList *top)
 {
   int i, n;
-  GtkToggleButton *btn;
   GSList *list;
 
   n = g_slist_length(top);
   for (i = 0, list = top; i < n; i++, list = list->next) {
+    GtkToggleButton *btn;
     btn = GTK_TOGGLE_BUTTON(list->data);
     if (gtk_toggle_button_get_active(btn)) {
       return i;
@@ -353,17 +357,17 @@ LegendGaussDialogDiv(GtkWidget *w, gpointer client_data)
 static void
 LegendGaussDialogSetup(GtkWidget *wi, void *data, int makewidget)
 {
-  GtkWidget *w, *button, *hbox, *hbox2, *vbox, *table;
   GSList *func_list, *dir_list;
   struct LegendGaussDialog *d;
   char title[256];
-  int i;
 
   d = (struct LegendGaussDialog *) data;
   snprintf(title, sizeof(title), _("Legend Gaussian/Lorentzian/Parabola/Sin %d"), d->Id);
   gtk_window_set_title(GTK_WINDOW(wi), title);
 
   if (makewidget) {
+    GtkWidget *w, *button, *hbox, *hbox2, *vbox, *table;
+    int i;
     hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 4);
 
     button = NULL;
@@ -482,7 +486,7 @@ LegendGaussDialogClose(GtkWidget *w, void *data)
 {
   struct LegendGaussDialog *d;
   int ret, a, i, amp, wd, gx, gy;
-  double x, y = 0, tmp;
+  double y = 0, tmp;
   struct narray *parray;
 
   d = (struct LegendGaussDialog *) data;
@@ -520,6 +524,7 @@ LegendGaussDialogClose(GtkWidget *w, void *data)
 
   parray = arraynew(sizeof(int));
   for (i = 0; i <= d->Div; i++) {
+    double x;
     x = wd / ((double) (d->Div)) * i;
     if (d->Mode == 0) {
       tmp =
