@@ -33,11 +33,13 @@
 #include "nstring.h"
 #include "nconfig.h"
 #include "odraw.h"
+#include "oaxis.h"
 
 #include "gtk_liststore.h"
 #include "gtk_subwin.h"
 #include "gtk_combo.h"
 #include "gtk_widget.h"
+#include "gtk_presettings.h"
 
 #include "x11gui.h"
 #include "x11dialg.h"
@@ -954,6 +956,7 @@ PrefFontDialogClose(GtkWidget *w, void *data)
 
   d = (struct PrefFontDialog *) data;
 
+  presetting_set_fonts();
   if (d->ret == IDSAVE) {
     save_config(SAVE_CONFIG_TYPE_FONTS);
   }
@@ -1013,6 +1016,8 @@ MiscDialogSetupItem(GtkWidget *w, struct MiscDialog *d)
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(d->use_custom_palette), Menulocal.use_custom_palette);
   arraycpy(&(d->tmp_palette), &(Menulocal.custom_palette));
 
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(d->use_dark_theme), Menulocal.use_dark_theme);
+
   if (Menulocal.source_style_id) {
     GtkSourceStyleSchemeManager *sman;
     GtkSourceStyleScheme *style;
@@ -1284,6 +1289,10 @@ MiscDialogSetup(GtkWidget *wi, void *data, int makewidget)
     }
     d->decimalsign = w;
 
+    w = gtk_check_button_new_with_mnemonic(_("use _Dark theme"));
+    add_widget_to_table(table, w, NULL, FALSE, i++);
+    d->use_dark_theme = w;
+
     gtk_container_add(GTK_CONTAINER(frame), table);
     gtk_box_pack_start(GTK_BOX(vbox2), frame, TRUE, TRUE, 4);
 
@@ -1416,6 +1425,8 @@ MiscDialogClose(GtkWidget *w, void *data)
   }
   arraydel(&(d->tmp_palette));
 
+  menu_use_dark_theme_set(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(d->use_dark_theme)));
+
   d->ret = ret;
 
   source_style = gtk_source_style_scheme_chooser_get_style_scheme(GTK_SOURCE_STYLE_SCHEME_CHOOSER(d->source_style));
@@ -1706,6 +1717,25 @@ ViewerDialog(struct ViewerDialog *data, struct objlist *obj, int id)
   data->Clear = FALSE;
 }
 
+static void
+save_default_axis_config(void)
+{
+  int n;
+  struct objlist *obj;
+
+  obj = chkobject("axis");
+  if (obj == NULL) {
+    return;
+  }
+  n = chkobjlastinst(obj);
+  if (n < 0) {
+    return;
+  }
+  if (CheckIniFile()) {
+    exeobj(obj, "save_config", 0, 0, NULL);
+  }
+}
+
 void
 CmOptionSaveNgp(void *w, gpointer client_data)
 {
@@ -1749,6 +1779,8 @@ CmOptionSaveNgp(void *w, gpointer client_data)
   SetStatusBar(mes);
   SaveDrawrable(ngpfile, FALSE, FALSE, FALSE);
   ResetStatusBar();
+  menu_default_axis_size(&Menulocal);
+  save_default_axis_config();
   g_free(ngpfile);
   return;
 }
