@@ -29,12 +29,13 @@
 static int
 splinecheck(double d[],double mu[],double ram[],double x[],double y[], int num)
 {
-  double h1,h2;
+  double h1;
   int i;
 
   h1=x[1]-x[0];
   if (h1==0) return -1;
   for (i=1;i<num-1;i++) {
+    double h2;
     h2=x[i+1]-x[i];
     if ((h2==0) || (h1==0) || (h1+h2==0)) return -1;
     h1=h2;
@@ -45,12 +46,13 @@ splinecheck(double d[],double mu[],double ram[],double x[],double y[], int num)
 static void
 splinesetval(double d[],double mu[],double ram[],double x[],double y[], int num)
 {
-  double h1,h2,y1,y2;
+  double h1,y1;
   int i;
 
   h1=x[1]-x[0];
   y1=y[1]-y[0];
   for (i=1;i<num-1;i++) {
+    double h2, y2;
     h2=x[i+1]-x[i];
     y2=y[i+1]-y[i];
     ram[i]=h2/(h1+h2);
@@ -67,12 +69,12 @@ static int
 splinesolv(double d[],double mu[],double ram[],double x[],double y[], int num,double *xx)
 {
   int i;
-  double h;
 
   *xx=-mu[0]*0.5;
   d[0]=d[0]*0.5;
   mu[0]=ram[0]*0.5;
   for (i=1;i<num;i++) {
+    double h;
     h=2-mu[i]*mu[i-1];
     if (h==0) return -1;
     *xx=-mu[i]*(*xx)/h;
@@ -87,12 +89,12 @@ static int
 splinesolv2(double d[],double mu[],double ram[],double x[],double y[], int num,double *xx)
 {
   int i;
-  double h;
 
   *xx=-ram[num-1]*0.5;
   d[num-1]=d[num-1]*0.5;
   ram[num-1]=mu[num-1]*0.5;
   for (i=num-2;i>=0;i--) {
+    double h;
     h=2-ram[i]*ram[i+1];
     if (h==0) return -1;
     *xx=-ram[i]*(*xx)/h;
@@ -196,7 +198,7 @@ spline(double x[],double y[],double c1[],double c2[],double c3[],
            int num,int bc0,int bc1,double df0,double df1)
 {
   int i;
-  double h,xx,m;
+  double xx;
 
   if (splinecheck(c1,c2,c3,x,y,num)!=0) return -1;
   if (splineboundary(c1,c2,c3,x,y,num,bc0,bc1,df0,df1)!=0) return -1;
@@ -206,6 +208,7 @@ spline(double x[],double y[],double c1[],double c2[],double c3[],
   c3[num-1]=c1[num-1];
   for (i=num-2;i>=0;i--) c3[i]=c1[i]-c2[i]*c3[i+1];
   for (i=0;i<num-1;i++) {
+    double h, m;
      h=x[i+1]-x[i];
      m=c3[i];
      c3[i]=(c3[i+1]-m)/6/h;
